import _extends from '@babel/runtime/helpers/esm/extends';
import _objectSpread from '@babel/runtime/helpers/esm/objectSpread2';
import _objectWithoutProperties from '@babel/runtime/helpers/esm/objectWithoutProperties';
import { jsx, useBrand, useMediaQuery, getLabel, overrideReconciler } from '@westpac/core';
import { createContext, useContext } from 'react';
import PropTypes from 'prop-types';
import '@babel/runtime/helpers/defineProperty';
import { Heading } from '@westpac/heading';
import { Body } from '@westpac/body';

var _excluded$7 = ["state"];
// Component
// ==============================

var Header = function Header(_ref) {
  _ref.state;
      var rest = _objectWithoutProperties(_ref, _excluded$7);

  return jsx("div", rest);
}; // ==============================
// Styles
// ==============================


var headerStyles = function headerStyles(_, _ref2) {
  var look = _ref2.look;

  var _useBrand = useBrand(),
      COLORS = _useBrand.COLORS;

  var mq = useMediaQuery();
  var styleMap = {
    hero: {
      backgroundColor: COLORS.hero,
      borderColor: COLORS.hero,
      color: '#fff'
    },
    faint: {
      backgroundColor: COLORS.background,
      borderColor: COLORS.border,
      color: COLORS.text
    }
  };
  return mq({
    label: getLabel('panel-header'),
    padding: ['0.625rem 0.75rem', null, '0.625rem 1.5rem'],
    backgroundColor: styleMap[look].backgroundColor,
    borderBottom: "1px solid ".concat(styleMap[look].borderColor),
    borderTopRightRadius: "calc(0.1875rem - 1px)",
    borderTopLeftRadius: "calc(0.1875rem - 1px)",
    color: styleMap[look].color,
    '@media print': {
      borderBottom: '1px solid #000'
    }
  })[0];
}; // ==============================
// Attributes
// ==============================

var headerAttributes = function headerAttributes() {
  return null;
}; // ==============================
// Exports
// ==============================


var defaultHeader = {
  component: Header,
  styles: headerStyles,
  attributes: headerAttributes
};

var _excluded$6 = ["state"];
// Component
// ==============================

var Panel$1 = function Panel(_ref) {
  _ref.state;
      var rest = _objectWithoutProperties(_ref, _excluded$6);

  return jsx("div", rest);
};
// Styles
// ==============================


var panelStyles = function panelStyles(_, _ref3) {
  var look = _ref3.look;

  var _useBrand = useBrand(),
      COLORS = _useBrand.COLORS,
      SPACING = _useBrand.SPACING;

  var styleMap = {
    hero: {
      borderColor: COLORS.hero
    },
    faint: {
      borderColor: COLORS.border
    }
  };
  return {
    label: getLabel('panel'),
    marginBottom: SPACING(4),
    backgroundColor: '#fff',
    border: "1px solid ".concat(styleMap[look].borderColor),
    borderRadius: '0.1875rem',
    table: {
      overflow: 'hidden',
      //clip overflow for rounded corners
      marginBottom: 0,
      borderBottomRightRadius: "calc(0.1875rem - 1px)",
      borderBottomLeftRadius: "calc(0.1875rem - 1px)"
    },
    'table caption': {
      padding: ["".concat(SPACING(2), " ").concat(SPACING(2), " 0 ").concat(SPACING(2)), null, "".concat(SPACING(4), " ").concat(SPACING(4), " 0 ").concat(SPACING(4))]
    }
  };
}; // ==============================
// Attributes
// ==============================


var panelAttributes = function panelAttributes() {
  return null;
};
// Exports
// ==============================


var defaultPanel = {
  component: Panel$1,
  styles: panelStyles,
  attributes: panelAttributes
};

var _excluded$5 = ["state"];
// Component
// ==============================

var PanelHeading = function PanelHeading(_ref) {
  var headingTag = _ref.state.headingTag,
      rest = _objectWithoutProperties(_ref, _excluded$5);

  return jsx(Heading, _extends({
    tag: headingTag,
    size: 9
  }, rest));
};
// Styles
// ==============================


var headingStyles = function headingStyles() {
  var _useBrand = useBrand(),
      TYPE = _useBrand.TYPE;

  return _objectSpread(_objectSpread({
    label: getLabel('panel-heading')
  }, TYPE.bodyFont[400]), {}, {
    color: 'inherit'
  });
}; // ==============================
// Attributes
// ==============================


var headingAttributes = function headingAttributes() {
  return null;
}; // ==============================
// Exports
// ==============================


var defaultHeading = {
  component: PanelHeading,
  styles: headingStyles,
  attributes: headingAttributes
};

var pkg = {
	name: "@westpac/panel",
	version: "2.1.0",
	description: "Simple containers used to highlight content, available in two styles, with optional footer",
	homepage: "https://gel.westpacgroup.com.au/design-system",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/panel",
	blender: {
		recipe: "blender/recipe.js"
	},
	components: [
		{
			name: "Panel",
			src: "Panel.tsx"
		}
	],
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		},
		{
			name: "Jeremy Ortiz",
			email: "jeremy@jeremyortiz.io",
			url: "https://www.jeremyortiz.io/"
		},
		{
			name: "Flore Laforge",
			email: "florelaforge@gmail.com",
			url: "http://florelaforge.com/"
		}
	],
	license: "GPL-3.0+",
	scripts: {
		start: "PACKAGE_NAME=panel NODE_ENV=development webpack server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:all": "yarn test:integration",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	main: "dist/westpac-panel.cjs.js",
	module: "dist/westpac-panel.esm.js",
	dependencies: {
		"@babel/runtime": "^7.14.8",
		"@westpac/body": "^2.1.0",
		"@westpac/core": "^3.1.0",
		"@westpac/heading": "^2.1.0",
		"prop-types": "^15.7.2"
	},
	peerDependencies: {
		react: "^18.2.0"
	},
	devDependencies: {
		"@westpac/table": "^2.1.0",
		cypress: "^8.0.0",
		react: "^18.2.0",
		"start-server-and-test": "^1.12.6"
	}
};

var _excluded$4 = ["look", "heading", "headingTag", "children", "overrides"];
// Context and Consumer Hook
// ==============================

var PanelContext = /*#__PURE__*/createContext(null);
var usePanelContext = function usePanelContext() {
  var context = useContext(PanelContext);

  if (!context) {
    throw new Error('<Body/> and <Footer/> components should be wrapped in a <Panel>.');
  }

  return context;
}; // ==============================
// Component
// ==============================

var Panel = function Panel(_ref) {
  var look = _ref.look,
      heading = _ref.heading,
      headingTag = _ref.headingTag,
      children = _ref.children,
      componentOverrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, _excluded$4);

  var _useBrand = useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var defaultOverrides = {
    Panel: defaultPanel,
    Header: defaultHeader,
    Heading: defaultHeading
  };

  var state = _objectSpread({
    look: look,
    heading: heading,
    headingTag: headingTag,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$P = _overrideReconciler.Panel,
      Panel = _overrideReconciler$P.component,
      panelStyles = _overrideReconciler$P.styles,
      panelAttributes = _overrideReconciler$P.attributes,
      _overrideReconciler$H = _overrideReconciler.Header,
      Header = _overrideReconciler$H.component,
      headerStyles = _overrideReconciler$H.styles,
      headerAttributes = _overrideReconciler$H.attributes,
      _overrideReconciler$H2 = _overrideReconciler.Heading,
      Heading = _overrideReconciler$H2.component,
      headingStyles = _overrideReconciler$H2.styles,
      headingAttributes = _overrideReconciler$H2.attributes;

  return jsx(PanelContext.Provider, {
    value: {
      state: state
    }
  }, jsx(Panel, _extends({}, rest, {
    state: state
  }, panelAttributes(state), {
    css: panelStyles(state)
  }), jsx(Header, _extends({
    state: state
  }, headerAttributes(state), {
    css: headerStyles(state)
  }), jsx(Heading, _extends({
    state: state
  }, headingAttributes(state), {
    css: headingStyles(state)
  }), heading)), children));
}; // ==============================
// Types
// ==============================

Panel.propTypes = {
  /**
   * Panel look
   */
  look: PropTypes.oneOf(['hero', 'faint']).isRequired,

  /**
   * Panel heading text
   */
  heading: PropTypes.string.isRequired,

  /**
   * Panel heading tag
   */
  headingTag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]).isRequired,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Panel: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Header: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Heading: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};
var defaultProps = {
  look: 'hero',
  headingTag: 'h1'
};
Panel.defaultProps = defaultProps;

var _excluded$3 = ["state"];
// Component
// ==============================

var PanelBody$1 = function PanelBody(_ref) {
  _ref.state;
      var rest = _objectWithoutProperties(_ref, _excluded$3);

  return jsx(Body, rest);
};
// Styles
// ==============================


var bodyStyles = function bodyStyles() {
  var mq = useMediaQuery();

  var _useBrand = useBrand(),
      SPACING = _useBrand.SPACING;

  return mq({
    label: getLabel('panel-body'),
    padding: [SPACING(2), null, SPACING(4)]
  })[0];
}; // ==============================
// Attributes
// ==============================


var bodyAttributes = function bodyAttributes() {
  return null;
}; // ==============================
// Exports
// ==============================


var defaultBody = {
  component: PanelBody$1,
  styles: bodyStyles,
  attributes: bodyAttributes
};

var _excluded$2 = ["children", "overrides"];
// Component
// ==============================

var PanelBody = function PanelBody(_ref) {
  var children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, _excluded$2);

  var _useBrand = useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = usePanelContext();
  var defaultOverrides = {
    Body: defaultBody
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread({
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$B = _overrideReconciler.Body,
      Body = _overrideReconciler$B.component,
      bodyStyles = _overrideReconciler$B.styles,
      bodyAttributes = _overrideReconciler$B.attributes;

  return jsx(Body, _extends({}, rest, {
    state: state
  }, bodyAttributes(state), {
    css: bodyStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

PanelBody.propTypes = {
  /**
   * Panel body content
   */
  children: PropTypes.node,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Body: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

var _excluded$1 = ["state"];
// Component
// ==============================

var Footer = function Footer(_ref) {
  _ref.state;
      var rest = _objectWithoutProperties(_ref, _excluded$1);

  return jsx("div", rest);
}; // ==============================
// Styles
// ==============================


var footerStyles = function footerStyles() {
  var _useBrand = useBrand(),
      COLORS = _useBrand.COLORS;

  var mq = useMediaQuery();
  return mq({
    label: getLabel('panel-footer'),
    padding: ['0.625rem 0.75rem', null, '0.625rem 1.5rem'],
    backgroundColor: COLORS.light,
    borderTop: "1px solid ".concat(COLORS.border),
    borderBottomRightRadius: "calc(0.1875rem - 1px)",
    borderBottomLeftRadius: "calc(0.1875rem - 1px)"
  })[0];
}; // ==============================
// Attributes
// ==============================


var footerAttributes = function footerAttributes() {
  return null;
}; // ==============================
// Exports
// ==============================


var defaultFooter = {
  component: Footer,
  styles: footerStyles,
  attributes: footerAttributes
};

var _excluded = ["children", "overrides"];
// Component
// ==============================

var PanelFooter = function PanelFooter(_ref) {
  var children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _useBrand = useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = usePanelContext();
  var defaultOverrides = {
    Footer: defaultFooter
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread({
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$F = _overrideReconciler.Footer,
      Footer = _overrideReconciler$F.component,
      footerStyles = _overrideReconciler$F.styles,
      footerAttributes = _overrideReconciler$F.attributes;

  return jsx(Footer, _extends({}, rest, {
    state: state
  }, footerAttributes(state), {
    css: footerStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

PanelFooter.propTypes = {
  /**
   * Panel footer content
   */
  children: PropTypes.node,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Footer: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

export { PanelBody as Body, PanelFooter as Footer, Panel };
